# prosodia
[![Build Status](https://travis-ci.org/macbeth322/prosodia.svg?branch=master)](https://travis-ci.org/macbeth322/prosodia)

`prosodia` is a library to parse arbitrary grammars and then apply a
deterministic transformation.

## TODOs
- Add a validity check to a language that checks that there are no unused rules
- use Optional for type checking if a repeat term is exactly zero or one?
- use proper TaggedUnion library?
- allow switches as syntax transformations
